package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````,",```````!``````````'"Q````
M`````````$``.``)`$``'@`=``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````""B````````(*(`````````
M$`````````$````&````D*L```````"0NP```````)"[````````L`0`````
M```@!0`````````0`````````@````8```"XJP```````+B[````````N+L`
M```````P`@```````#`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````-)H````````TF@```````#2:````````'`$````````<`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````)"K````````D+L```````"0NP``
M`````'`$````````<`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,````"``````````0`
M```4`````P```$=.50#$XL.AH*B!#/2M5%JC<&HX`M"WHF$```!C````````
M``````!'````!0``````````````)P``````````````)0```!L`````````
M.0````D```!9`````````!8```!!````0@```#L```!2````7P````<````Z
M```````````````$````50```#T``````````````$0```!,````2```````
M``!.````8@````T`````````+0`````````T`````````$D```!4````0```
M`#4`````````7@```%@`````````%`````@``````````````$L````A````
M+P```"8````"````````````````````&``````````````````````````!
M````(`````L````R````8````#P`````````)````%8```!&````*````%$`
M``!#````,0```"X`````````/@```````````````````%<```!%````````
M`"D```!-````,`````P````S`````P``````````````````````````````
M``````````````````````````````````````````!:````````````````
M`````````````````````````````````````````&$`````````%P``````
M`````````````%T````3`````````!(`````````6P````````!3````(P``
M```````_```````````````B```````````````L````'```````````````
M`````"L`````````&0``````````````-P`````````V````"@```%P````X
M````*@`````````````````````````0```````````````&`````````!H`
M```=````'@`````````?```````````````5````$0````X`````````````
M``````!*````````````````````3P`````````/````````````````````
M`````%```````````````!$````_````!`````@````@'!``!4`$AB@"0`20
MA@"$@HD`(DD@!`BXHA%-N@`&"@`````_````0@```$4```!&````3P```%``
M``!2````5@```%<```!9````6@```%T```!?````80``````````````;L7?
M'\[>1RUK?YI\+L6;MB#_Y`[59-1\V7%8'.)'Q@%"^M>'K$OCP/+;TQVZXY)\
MPN4_+/JA;&"R`8MOF4_#FVL)0]9FK\QFQ;F<0$)%U>S$B060B`=PTSGRBQP-
M%.*>VLWCGC-BV^T5C"7,##J7"U:DFY:GW:-K?JF<F]%ESFW@IP(*:QJ>4`J*
M$%>CX/M)`````````````````````````````````````.$````2````````
M`````````````````)`"```2`````````````````````````*$!```2````
M``````````````````````("```2`````````````````````````-@!```2
M``````````````````````````$````@``````````````````````````D"
M```2`````````````````````````(`"```2````````````````````````
M`!X"```2`````````````````````````$4!```2````````````````````
M`````&@"```2`````````````````````````&`"```2````````````````
M`````````'0````2`````````````````````````&(#```2````````````
M`````````````-P````2`````````````````````````#H"```2````````
M`````````````````#,"```2`````````````````````````/$!```2````
M`````````````````````'D"```2`````````````````````````(D"```2
M`````````````````````````.`!```2`````````````````````````#<!
M```2``````````````````````````4!```2````````````````````````
M`',!```2`````````````````````````.@!```2````````````````````
M`````/@"```2`````````````````````````&`!```2````````````````
M`````````!<"```2`````````````````````````)4!```2````````````
M`````````````-P"```2`````````````````````````-4"```2````````
M`````````````````!,!```2`````````````````````````!T````@````
M`````````````````````$X"```2`````````````````````````%0````2
M`````````````````````````,8!```2`````````````````````````+(!
M```2`````````````````````````&P!```2````````````````````````
M`(,````2`````````````````````````(\````2````````````````````
M`````"P!```2`````````````````````````/(````2````````````````
M`````````$8````2`````````````````````````.8````2````````````
M`````````````%4!```2`````````````````````````,`````2````````
M``````````````````\"```2`````````````````````````)H!```2````
M`````````````````````,8"```2`````````````````````````)\"```2
M`````````````````````````&,````2`````````````````````````,X"
M```2`````````````````````````"P"```2````````````````````````
M`*0````2`````````````````````````",!```2````````````````````
M`````%4"```2`````````````````````````-,!```2````````````````
M`````````(T!```2`````````````````````````$`"```2````````````
M`````````````"P````@`````````````````````````"4"```2````````
M`````````````````+@"```2`````````````````````````&L#```2``\`
M0#X```````!3`````````)<#```2``\`D#0````````=!P```````.D"```2
M``\`\"`````````R`@```````#\#```2``\`$"T````````%`````````"L$
M```2``\`("T````````:`@```````&D$```2``\`L#L```````"-`@``````
M`!<$```0`!L`0,```````````````````'X#```2``\`0"\````````B````
M`````*0#```2``\`$%4```````"2`0```````+P#```1`!$`N%D````````$
M`````````'X!```1`!8`H+L````````3`````````/L#```0`!L`L,``````
M`````````````",$```2``\`P"L````````P`````````#@$```2``\`P#,`
M``````#.`````````$H$```2``\`4#$```````!=`````````%@$```2``\`
ML#$```````"R`````````*\#```0`!D``,```````````````````(L#```2
M``\`<"\```````!$`````````.X"```1`!L`:,`````````(`````````'<#
M```0`!H`0,```````````````````.\"```A`!L`:,`````````(````````
M`/$#```1`!D`(,`````````(`````````'("```1`!L`@,`````````(````
M`````"\#```2``\`?ED````````$`````````.$#```2``\`_E@```````!G
M`````````+4#```2``\`,",````````K`````````&`$```2``\`L%0`````
M``!4`````````+$#```@`!D``,```````````````````-$````1`!L`0,``
M```````$`````````/`"```A`!L`:,`````````(`````````%`#```2``\`
MD#,````````D`````````*D"```B`````````````````````````,L#```2
M``\`0"P```````#!``````````T$```2``\`L%8````````S`@```````+,`
M```1`!L`8,`````````!```````````$```2``\`P"\```````"&`0``````
M``!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?
M<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R
M;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`
M4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L
M7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?
M<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R
M;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A
M9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L<V5E:S8T
M`')E860`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`<'1H<F5A9%]G971S<&5C
M:69I8P!?7W-T<&-P>5]C:&L`97AI=`!S=')N8VUP`'-T<G)C:'(`8VQO<V5D
M:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC
M:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`')M9&ER`%]?9G!R:6YT
M9E]C:&L`;65M8W!Y`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D
M97)R`&=E='5I9`!R96%D;&EN:P!S=')C:'(`7U]V9G!R:6YT9E]C:&L`<F5A
M9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A
M8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W)E
M9VES=&5R7V%T9F]R:P!L:6)P97)L+G-O`&QI8G!T:')E860N<V\N,`!L:6)C
M+G-O+C8`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S
M97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`'!A<E]B
M87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?
M7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!P87)?:6YI=%]E
M;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G
M`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<&%R7V1I90!S:&%?
M:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?
M,BXQ-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`1TQ)0D-?,BXS+C0`+W5S<B]L
M:6(O<&5R;#4O-2XR-BXQ+W@X-E\V-"UL:6YU>"UT:')E860M;75L=&DO0T]2
M10`````"``,`!``"``(``0`"``(``@`!``(``@`!``(``0`"``(`!0`"``(`
M`@`!``$``0`"``8``0`"``0``@`"``$``0`'``$``P`$``(``0`!``$``0`!
M``$``0`!``(`!``"``(``0`"``(``0`!``(``@`$``,``0`"``,``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``@`!``(``0`"``$``0`!
M``$``0`!``(``0`"``$``0`!``$```````$``0`5`P``$````"````!U&FD)
M```$`'\$`````````0`%`"4#```0`````````)21E@8```<`BP0``!````!R
M&6D)```&`)8$```0````%&EI#0``!0"B!```$````'09:0D```,`K`0``!``
M``!U&FD)```"`'\$````````D+L````````(`````````#`D````````F+L`
M```````(`````````/`C````````",`````````(``````````C`````````
M(,`````````(`````````+!<````````*,`````````(`````````/!8````
M````,,`````````(`````````'!9````````.,`````````(`````````)!9
M````````N+\````````&````!@``````````````P+\````````&````"@``
M````````````R+\````````&````'@``````````````T+\````````&````
M(0``````````````V+\````````&````*@``````````````X+\````````&
M````,P``````````````Z+\````````&````/```````````````\+\`````
M```&````7@``````````````H+L````````%````20``````````````0,``
M```````%````6P``````````````8,`````````%````80``````````````
M:,`````````%````40``````````````@,`````````%````50``````````
M`````+X````````'`````0``````````````"+X````````'`````@``````
M````````$+X````````'`````P``````````````&+X````````'````!```
M````````````(+X````````'````!0``````````````*+X````````'````
M!P``````````````,+X````````'````"```````````````.+X````````'
M````"0``````````````0+X````````'````"P``````````````2+X`````
M```'````#```````````````4+X````````'````#0``````````````6+X`
M```````'````#@``````````````8+X````````'````#P``````````````
M:+X````````'````$```````````````<+X````````'````$0``````````
M````>+X````````'````$@``````````````@+X````````'````$P``````
M````````B+X````````'````%```````````````D+X````````'````%0``
M````````````F+X````````'````%@``````````````H+X````````'````
M%P``````````````J+X````````'````&```````````````L+X````````'
M````&0``````````````N+X````````'````&@``````````````P+X`````
M```'````&P``````````````R+X````````'````'```````````````T+X`
M```````'````'0``````````````V+X````````'````'P``````````````
MX+X````````'````(```````````````Z+X````````'````(@``````````
M````\+X````````'````(P``````````````^+X````````'````)```````
M`````````+\````````'````)0``````````````"+\````````'````)@``
M````````````$+\````````'````)P``````````````&+\````````'````
M*```````````````(+\````````'````*0``````````````*+\````````'
M````*P``````````````,+\````````'````+```````````````.+\`````
M```'````+0``````````````0+\````````'````+@``````````````2+\`
M```````'````+P``````````````4+\````````'````,```````````````
M6+\````````'````,0``````````````8+\````````'````,@``````````
M````:+\````````'````-```````````````<+\````````'````-0``````
M````````>+\````````'````-@``````````````@+\````````'````-P``
M````````````B+\````````'````.```````````````D+\````````'````
M.0``````````````F+\````````'````.@``````````````H+\````````'
M````.P``````````````J+\````````'````/0``````````````L+\`````
M```'````/@``````````````2(/L"$B+!86B``!(A<!T`O_02(/$",,`````
M``````#_-8J@``#_)8R@```/'T``_R6*H```:`````#IX/____\E@J```&@!
M````Z=#_____)7J@``!H`@```.G`_____R5RH```:`,```#IL/____\E:J``
M`&@$````Z:#_____)6*@``!H!0```.F0_____R5:H```:`8```#I@/____\E
M4J```&@'````Z7#_____)4J@``!H"````.E@_____R5"H```:`D```#I4/__
M__\E.J```&@*````Z4#_____)3*@``!H"P```.DP_____R4JH```:`P```#I
M(/____\E(J```&@-````Z1#_____)1J@``!H#@```.D`_____R42H```:`\`
M``#I\/[___\E"J```&@0````Z>#^____)0*@``!H$0```.G0_O___R7ZGP``
M:!(```#IP/[___\E\I\``&@3````Z;#^____)>J?``!H%````.F@_O___R7B
MGP``:!4```#ID/[___\EVI\``&@6````Z8#^____)=*?``!H%P```.EP_O__
M_R7*GP``:!@```#I8/[___\EPI\``&@9````Z5#^____);J?``!H&@```.E`
M_O___R6RGP``:!L```#I,/[___\EJI\``&@<````Z2#^____):*?``!H'0``
M`.D0_O___R6:GP``:!X```#I`/[___\EDI\``&@?````Z?#]____)8J?``!H
M(````.G@_?___R6"GP``:"$```#IT/W___\E>I\``&@B````Z<#]____)7*?
M``!H(P```.FP_?___R5JGP``:"0```#IH/W___\E8I\``&@E````Z9#]____
M)5J?``!H)@```.F`_?___R52GP``:"<```#I</W___\E2I\``&@H````Z6#]
M____)4*?``!H*0```.E0_?___R4ZGP``:"H```#I0/W___\E,I\``&@K````
MZ3#]____)2J?``!H+````.D@_?___R4BGP``:"T```#I$/W___\E&I\``&@N
M````Z0#]____)1*?``!H+P```.GP_/___R4*GP``:#````#IX/S___\E`I\`
M`&@Q````Z=#\____)?J>``!H,@```.G`_/___R7RG@``:#,```#IL/S___\E
MZIX``&@T````Z:#\____)>*>``!H-0```.F0_/___R7:G@``:#8```#I@/S_
M__\E"I\``&:0``````````!54TB#[#B)?"0<2(ET)!!(C7PD'$B)5"0(2(UT
M)!!(C50D"&1(BP0E*````$B)1"0H,<#H*/[__TB+-:F>``!(BSVJG@``2(GR
MZ&`X``"`/1N?````=2_H=/W__TB%P$B)!5*?```/A+P!``!(B<?HK/S__XL]
MUIX``.@!_O__QH#1"````(L]Q)X``.CO_?__@(BJ!````HL]LIX``.C=_?__
M@(BJ!````8M$)!R->`2-6`-(N/________\?2&/_2#G'#X<@`0``2,'G`^@M
M_?__2(M\)!!(C0W1.0``1(M$)!Q(B07%G@``2(L72(E("$B-#;HY``!!@_@!
M2(E(&$B)$$B+%26>``!(B5`0#X[+````2(/'"$&#P`.^!````&8/'T0``$B+
M#TACUH/&`4B#QPA$.<9(B0S0=>I(8_9(P>8#2(L];)X``$C'!#``````2(TU
MI0D``$4QP$B)P8G:Z(C]__^%P'1F2(L]19X``$B-7"0DZ#/\__](C3WH-P``
MB<5(B=XQP.C``0``2(7`="I(BST<G@``Z)_[___H*OW__TB+7"0H9$@S'"4H
M````B>AU:TB#Q#A;7<-(BSWBG0``2(7_=#3H@!L``.O#2(L]WYT``.BB_?__
MZXR^(````.E;____2(TUOY@``$B-/28W```QP.BQ_/__2(T]&S<``$B)WNA"
M`0``2(7`2(G'2(D%C9T```^$=/___^NHZ$C[__^_`0```.AN_?__9BX/'X0`
M``````\?0``Q[4F)T5Y(B>)(@^3P4%1,C04X-@``2(T-L34``$B-/9S]____
M%6Z<``#T#Q]$``!(C3W!G```54B-!;F<``!(.?A(B>5T&4B+!3J<``!(A<!T
M#5W_X&8N#Q^$``````!=PV9F+@\?A```````#Q\`2(T]@9P``$B--7J<``!5
M2"G^2(GE2,'^`TB)\$C!Z#](`<9(T?YT&$B+!1F<``!(A<!T#%W_X&8/'X0`
M`````%W#9F8N#Q^$```````/'P"`/9&<````=2](@SWOFP```%5(B>5T#$B+
M/?J;``#HS?S__^A(____Q@5IG````5W##Q^``````//#9@\?1```54B)Y5WI
M9O___V8/'T0``$%7059!54%455-(@^P(2(7_#X2Q````3(L]"IP``$V%_P^$
MH0````^V!X3`=`0\/75>13'D28L?2(7;=#E)B?5)B?Y-8^1,B?T/'X``````
M3(GB3(GV2(G?Z!+Y__^%P'4'0H`\(SUT1TB#Q0A(BUT`2(7;==I(@\0(2(G8
M6UU!7$%=05Y!7\,/'X0``````$F)_$F#Q`%!#[8$)(3`=`0\/77O02G\ZXP/
M'X``````3"G]2HU<(P%(P?T#08EM`.NT9@\?1```,=OKJ@\?0`!54TB)_4B#
M[!AD2(L$)2@```!(B40D"#'`2(U<)`1FD#'`2(G>2(GOZ`/___](A<!T-DAC
M5"0$2(L%&IL``$B-!-!(BU`(2(722(D0=-)FD$B#P`A(BU`(2(722(D0=?#K
MOF8/'T0``$B+1"0(9$@S!"4H````=0=(@\086UW#Z,SX__]F9BX/'X0`````
M`)!!5T%6055!5%532(GS2(G]2(/L*&1(BP0E*````$B)1"08,<`QP(`^/0^4
MP$@!PTB)W^AY^/__2(UT)!1)B<1(B>\QP.A7_O__2(7`#X0.`0``2(G'28G%
MZ%/X__],.>`/@^(```!,8W0D%$G!Y@,/MD4`A,`/A*T!```\/0^$I0$``$B)
MZ.L-#Q^$``````"`^CUT"TB#P`$/MA"$TG7P2"GH2)A,`S4<F@``2HU\(`+H
M*OG__TB%P$F)!@^$>P$``$AC5"042(L%^ID``$B-30%(BQ30#[9%`#P]B`)T
M)H3`=1#K(&8N#Q^$```````\/7022(/!`0^V0?](@\(!A,"(`G7JQ@(],<`/
M'T0```^V#`.(3`(!2(/``83)=?`QP$B+="089$@S-"4H````#X41`0``2(/$
M*%M=05Q!74%>05_##Q\`2(/#`0^V0_])@\4!A,!!B$7_=>SKPF:03(L]89D`
M`$F#/P`/A+\```!,B?@QTNL+#Q^$``````!$B>I(@\`(1(UJ`4B#.`!U[XUR
M`TAC]DC!Y@.+!4^9``"%P'5;2(GWQP4^F0```0```.@I^/__2(7`#X1]````
M36/%3(G^2(G'3HTTQ0````!,B40D"$R)\NBB^/__3(M$)`A(B<%(B07;F```
M2L=$P0@`````1(EL)!3I;_[__TR)_^A8^/__2(7`2(G!2(D%LY@``'0F36/%
M3HTTQ0````#KR0\?0``QP.EV_O__D+X0````13'MZ5[___^X_____^G;_O__
MZ'3V__\/'T``05=!5D%505154TB![+@```!D2(L$)2@```!(B80DJ````#'`
M2(7_=`B`/P!)B?YU+TB+A"2H````9$@S!"4H````#X4L`0``2('$N````%M=
M05Q!74%>05_#9@\?1```Z*OU__](A<!(B<-TQ$B-1"002(TM5#$``$R-)4PQ
M``!,C3U(,0``2(D$)$B)W^BM]___2(7`#X2\````3(U($[D"````2(GO3(G.
M\Z8/E\`<`(3`=-6Y`P```$R)SDR)Y_.F#Y?`'`"$P'2_3(GW3(E,)`CHA_7_
M_TR+3"0(28G%3(G/Z'?U__]!C7P%`DAC_^B:]O__3(M,)`A)B<5(B<=-B?!,
MB?E(Q\+_____O@$````QP.C&]___2(L4)+\!````3(GNZ-7T__^#^/],B>]T
M$(M$)"@E`/```#T`0```="KH:/3__TR)[^@P]/__Z3;___\/'P!(B=_H@/7_
M_TR)]^CH]/__Z<3^___HCO[__^O4Z/?T__\/'X``````4TB)_DB)^[\!````
M2('LH````$B)XF1(BP0E*````$B)A"28````,<#HXO;__X7`=3Z+5"08@>(`
M\```@?H`0```=#2!^@"@``!T+$B+C"28````9$@S#"4H````=3!(@<2@````
M6\,/'X0``````#'`Z]@/'T``O@(```!(B=_H2_;__X7`#Y3`#[;`Z[WH7/3_
M_V9F+@\?A```````D$%6055)B?9!5%5)B?Q32(T]H"\``+K_#P``2('L$!``
M`$B)XTB)WF1(BP0E*````$B)A"0($```,<#H@?/__X7`#XZ)````C5#_1(LM
MWY4``$ACZH`\+`!T5DACZ$B)ZKXO````2(G?Z(/T__](A<!T1D2)[^CF]/__
M2(GI2(G:3(GF2(G'Z,7U__](BX0D"!```&1(,P0E*````'4[2('$$!```%M=
M05Q!74%>PV:0A=)UJ0\?0`!$B>_HH/3__TR)\DR)YDB)Q^C2\___Z[M$BRU9
ME0``Z]_H<O/__V:04TB)_KH`$```2('L$!```$B)XTB)WV1(BP0E*````$B)
MA"0($```,<#H0O3__TB#Z`%(.=AW%>L8#Q^``````,8``$B#Z`%(.=AT!8`X
M+W3OOB\```!(B=_H0O/__TB%P'0U2#G8=RA(B=_H8/7__TB+C"0($```9$@S
M#"4H````=3Q(@<00$```6\,/'T``Q@``Z],/'P!(BX0D"!```&1(,P0E*```
M`'442('$$!```$B-/10N``!;Z1'U___HK/+__V9F+@\?A```````D$B#[`B+
M/7:4``#HH?/__TB+%>J3``!(C0U+;@``2(TU\"T``$B)QTB#Q`CIP//__TB#
M[`B+/4:4``#H<?/__TB)Q^BY____BSTSE```Z%[S__],C05D+P``2(T5D`\`
M`$B--<DM``!%,<E(B<=(@\0(3(G!Z;?S__\/'X``````55-(@>PH(```9$B+
M!"4H````2(F$)!@@```QP$B)XTB-K"00$```Z'3Q__],C0U=+0``2(T-BRT`
M`$&)P+H!$```O@$```!(B=\QP.@_]/__N@`0``!(B>Y(B=_H+_'__X7`>%.-
M>`%(B<-(8__HS?+__TB%P$B)P7082&/;2(GN2(G'2(G:Z'3R__](B<'&!!@`
M2(N4)!@@``!D2#,4)2@```!(B<AU$TB!Q"@@``!;7<,/'T0``#')Z]?H7_'_
M_V9F+@\?A```````#Q]``.DK____9F8N#Q^$``````!!5T%6055!5$F)]%53
M2(G[2(T]VBP``$B![+@0``!D2(L$)2@```!(B80DJ!```#'`2(UT)`SHY?;_
M_[XO````2(G?2(G%Z!7Q__](A<!T0$B-/:,L``!(B=XQP.@?^/__2(G82(N,
M)*@0``!D2#,,)2@````/A9H!``!(@<2X$```6UU!7$%=05Y!7\,/'P!,B>?H
M"//__TB--6@L``!(B<?HB?+__TB%P$F)QW2A08`_`$R-I"2@````3(UL)!`/
MA.L```!F+@\?A```````2(7M=!-,B?Y(B>_H(/'__X7`#X2E````3(G_Z$#P
M__])C50'_TF)QDDYUW,G@#HO=`OK(`\?0`"`.B]U#,8"`$B#Z@%).==U[TR)
M_^@/\/__28G&2(G?Z`3P__])C40&`4@]_P\```^'$____TB#[`A(C0W%+```
M3(T-NBL``%--B?BZ`!```+X!````3(GG,<#H2?+__TR)ZDR)YK\!````Z%GO
M__^%P%I9=1"+1"0H)0#P```]`(```'1;2(TU<RL``#'_Z)7Q__](A<!)B<</
MA*G^__]!@#\`#X4?____2(7M=!I(C3W@*@``N0(```!(B>[SI@^7P!P`A,!T
MO4&^`0```$R-/<`J``#I0O___V8/'T0``+X!````3(GGZ"OQ__^%P'642(T]
M^BH``$R)YNAX]O__3(GGZ)#Q___I3_[__^@F[___9@\?1```4[XO````2(G[
MZ$+O__](C5`!2(7`2`]%VDB)WUOI7O'__V9F+@\?A```````#Q\`2(7_="N`
M/P!T)E-(B?OHS>[__TB#P`%(/0`0``!W(4B)WUOI6/O__P\?A```````2(T]
M%BH``.D4\?__#Q]``#'`6\-F9BX/'X0``````)!32(T]8RH``$B#[!!D2(L$
M)2@```!(B40D"#'`2(U<)`3H*O7__TB-/4<J```QP.@<]?__2(T]02H``#'`
MZ`[U__](C3T\*@``,<#H`/7__TB-/34J```QP.CR]/__2(T]-RH``#'`Z.3T
M__](C3W>*0``,<#HUO3__TB-/2<J```QP.C(]/__2(T](RH``#'`Z+KT__](
MC3T?*@``,<#HK/3__TB-/:\I```QP.B>]/__2(T]#2H``#'`2(G>Z+WS__](
MA<!T$4B-/>,I``!(B<8QP.@']?__2(T]]RD``#'`2(G>Z);S__](A<!T$4B-
M/?,I``!(B<8QP.C@]/__2(T][2D``#'`2(G>Z&_S__](A<!T0DB-/30I``!(
MB<8QP.BY]/__2(TUYRD``$B-/5<I```QP.BD]/__2(M$)`AD2#,$)2@```!U
M-4B#Q!!;PV8/'T0``$B-/:4I```QP$B)WN@7\___2(7`=+E(C3TS*0``2(G&
M,<#H8?3__^NFZ!KM__]F+@\?A```````2(/L&$B-/0TI``!D2(L$)2@```!(
MB40D"#'`2(UT)`3HR_+__S'22(7`=!4/M@`\,`^4PH3`#Y3`"<*#\@$/MM)(
MBTPD"&1(,PPE*````(G0=05(@\08P^BS[/__#Q\`2('LV````(3`2(ET)"A(
MB50D,$B)3"0X3(E$)$!,B4PD2'0W#RE$)%`/*4PD8`\I5"1P#RF<)(`````/
M*:0DD`````\IK"2@````#RFT)+`````/*;PDP````&1(BP0E*````$B)1"08
M,<!(C80DX````$B)^DB)X;X!````2(L]2XX``$B)1"0(2(U$)"#'!"0(````
MQT0D!#````!(B40D$.@HZ___O_\```#H+N[__V9F+@\?A```````#Q\`0515
MN@(```!3,?9!B?Q(@>P0``$`9$B+!"4H````2(F$)`@``0`QP.@#[O__2(UH
M_TB)Z$C!^#](P>@P2(U4!0`/M])(*<)(*=4/B*0```!(B>,/'T0``#'22(GN
M1(GGZ,OM__](@_C_#X2.````N@@``0!(B=Y$B>?H(>S__X/X_P^$@P```$B8
M2(/X!W902(U$`_A(.=AR1DB-%?^,``#K#@\?1```2(/H`4@YV'(O2(L*2#D(
M=>](*=U(`>A(B[0D"``!`&1(,S0E*````'5'2('$$``!`%M=05S#9I!(@>T`
M``$`2(']``#__P^%9/___TC'P/_____KPDB-/6,G```QP.@U_O__2(T]8B<`
M`#'`Z"?^___HTNK__V:02(/L".C7ZO__B<?H@.K__TB%P'0+2(L`2(/$",,/
M'P`QP.OT9F8N#Q^$``````"005152(G]4TB-/2(G``!(@^P09$B+!"4H````
M2(E$)`@QP$B-="0$Z%3P__](A<!T"(`X`$B)PW4O2(T]\"8``$B)[C'`Z);Q
M__](BT0D"&1(,P0E*````'5O2(/$$%M=05S##Q]$``!(B>_H(.K__TB)WTF)
MQ.@5ZO__28U\!`+H.^O__TB#[`A,C0W7)0``2(T-UB8``%-(Q\+_____2(G'
M28G$28GHO@$````QP.A<[/__2(T]=28``$R)YC'`Z!OQ__]86NN!Z-+I__]F
MD$%7059!54%428G]55-(C3UM)0``2('L>`$``&1(BP0E*````$B)A"1H`0``
M,<!(C05')@``3(UD)!Q(QT0D,`````!(QX0DB`````````!(QT0D4`````!(
MB40D($B-!<DD``!,B>9(B40D*$B-!:8E``!(B40D8$B-!9,E``!(B40D:$B-
M!?8E``!(B40D<$B-!9@E``!(B40D>$B-!>8E``!(B80D@````$B-!;XE``!(
MB40D0$B-!<\E``!(B40D2#'`Z.;N__](A<!T"8`X``^%:`(``#'`Z"'^__](
MA<!(B<,/A*4"``!(B=_HS>C__TB-?``!Z//I__^`.P!)B<9T-4R-/8HE``!,
MB?601`^V`TB)[S'`3(GY2,?"_____[X!````2(/#`4B#Q0+H"^O__X`[`'76
M2(U<)&!(C3W3)```ZQ@/'X0``````$B#PPA(BSM(A?\/A(@!```QP$R)YNA&
M[O__2(7`2(G%=-Z`.`!TV4B)Q^AA\___A<!TS4B)[^BEZO__2(7`28G`#X11
M`0``9@\?A```````3(G"BPI(@\($C8'__O[^]]$AR"6`@("`=.F)P<'I$*F`
M@```#T3!2(U*`D@/1-&)P0#!3(GQ2(/:`TPIPHLQ2(/!!(V&__[^_O?6(?`E
M@("`@'3IB<9,B40D",'N$*F`@```#T3&2(UQ`D@/1,Z)QD``QDB#V0-,*?&-
MG`H$!```2&/;2(G?Z,3H__])B<=(C05N)```059,C0U:(P``2(T-520``$C'
MPO____]03(M$)!B^`0```$R)_S'`Z-[I__],B?^^P`$``.C!YO__@_C_7T%8
M=1+HA.;__T2+"$&#^1$/A5D$``!(C90DD````$R)_K\!````Z%+I__^%P(G%
M=1>+A"2H````)0#P```]`$````^$10$``$F+30!(BSTJB0``2(T5BR0``$V)
M^+X!````,<`QV^A"Z?__Z7T````/'T0``#'M9@\?1```2&/%2(M<Q"!(A=MT
M.X`[`'0V2(G?@\4!Z-/Q__^%P'3?2(G?Z!?I__](A<!)B<`/A7O^__](8\5(
MBUS$($B%VW7+9@\?1```13'`Z6#^__](B<=(B40D".CC^___2(M$)`A(B<?H
MUNC__TB)PP\?`$B+E"1H`0``9$@S%"4H````2(G8#X6>`P``2('$>`$``%M=
M05Q!74%>05_##Q]``$B-/=DB```Q[4B%_W0F9I`QP$R)YH/%`>@#[/__2(7`
M=`6`.`!U*4ACQ4B+?,1`2(7_==R_#0```$B-':4B``#H&^?__TF)QNDH_?__
M#Q\`2(G'Z$CH__](A<!(B<,/A??\___KP68N#Q^$``````!$B[0DK````.C3
MY?__03G&#X6E_O__BX0DJ````"7_`0``/<`!```/A8[^__](B=_HN^;__TB-
M/2\B``!(B<-,B>8QP.AGZ___2(7`#X1>`0``28M]`$B)QN@R]/__2(7`28G$
M#X1&`0``3(GGZ$[E__^#^`-^04ACT$B-/2@B``"Y!0```$F-=!3\\Z8/E\*`
MV@"$TG4A@_@$#X0``@``@^@$2)A!@'P$_R\/A.\!```/'X``````,<#H`?C_
M_X7`=14Q]DR)Y^BSYO__A<!!B<0/A>@```!(C35F(0``2(T]\B```$R-)0`B
M```QP$R-+:,@``#H%>S__^A0Y/__051,C0V0(```4$B-#;PA``!(Q\+_____
M38GXO@$```!(B=\QP.@6Y___6%KK0V:0Z,OC__^#.!%U2>@1Y/__@\4!2(/L
M"$B-#8XA``!!5%5-B>E038GX2,?"_____[X!````2(G?,<#HT^;__TB#Q""^
MP`$``$B)W^BRX___@_C_=*U,B?_H5>/__TB-/>\?``!(B=XQP.ATZ___2(G?
MZ(SY___IM_W__P\?@`````!-BV4`Z;'^__\/'X``````B<?H&?C__TB%P$F)
MQ0^(!?___TB-</9,C;0D*@$``#'21(GGZ"?F__^Z!@```$R)]D2)Y^B'Y/__
M2(/X!@^%!P$``(L%AU\``#F$)"H!```/A<+^__\/MP5W7P``9D$Y1@0/A;#^
M__])C77.2(VL)#`!```QTD2)Y^C2Y?__NB@```!(B>Y$B>?H,N3__TB#^"@/
MA;(```!(C06.(```QH0D6`$```!(C0U0(```3(T-)!\``+X!````38GX4%5(
MQ\+_____2(G?,<#HL.7__UE>Z>S^__]F#Q^$``````!-BVT(387M#X0+_O__
M3(GOZ`OC__](@_@##X;Y_?__28UT!?Q(C3WC'P``N04```#SI@^7P!P`A,!-
M#T3EZ=;]__])BTT`2(L]`X4``$B-%20@``!-B?B^`0```#'`,=OH&^7__^E6
M_/__2(T]HA\``#'`Z`CV___HL^+__P\?`$%455-(@^P0BSV"A```9$B+!"4H
M````2(E$)`@QP.B=X___BSUGA```2(G#Z(_C__\/MI.X````2(U<)`1(C3U8
M'@``2(G>B)"Y````,<#H/.C__TB%P'0)@#@Q#X2N`0``,<#HI_/__XL](80`
M`.A,X___2(TU41\``+D#````N@$```!(B<?H\^+__TB%P$B)Q70U2(M`$(L]
M\8,``$R+(.@9X___2(T5(!\``$B)QTR)YNA'XO__2(M%$$B+*/9%#D`/A88!
M``"+/<"#``#HZ^+__TB--?<>``"Y`P```+H!````2(G'Z)+B__](A<!(B<5T
M/4B-/6T=```QP$B)WNB)Y___2(7`28G$#X0-`0``2(M%$(L]<X,``$B+*.B;
MXO__3(GB2(G'2(GNZ,WA__^+/5>#``#H@N+__TB--9`>``"Z`0```$B)Q^B.
MXO__BSTX@P``2(G%Z&#B__](C16#'@``2(GN2(G'Z([A__^+/1B#``#H0^+_
M_TB-/=T<``#&@+D`````2(G>,<#H^^;__TB%P$B)PTB)!4:#``!T/+[``0``
M2(G?Z%_@__^-4`&#^@%V"8/X$0^%J0```$B+1"0(9$@S!"4H````#X6R````
M2(/$$%M=05S#D$B+/0F#``#H]/;__TB%P$B)PTB)!>^"``!UJ4B-/8X>```Q
MP.CGX?__#Q^``````(!X`0`/A$_^___I0_[__Y!(BP7)@@``BSUC@@``3(L@
M2(M%$$B+*.B$X?__3(GF2(GOZ!GL___IY_[__P\?0`"+/3J"``#H9>'__TB)
M[DB)Q^BZX?__Z5_^__^)P4B+!7R"``!(C3T]'@``2(G:2(LP,<#H:.'__^@C
MX/__#Q\`4S'`2(G[Z`7S__^%P'0*2(7;=`6`.P!U!UO##Q]$``!(B=_H"/'_
M_TB)Q^C0\/__2(T]O1P``$B)QKD$````\Z8/E\`<`(3`=<](B=];Z5WI__]F
M+@\?A```````#Q\`05=!5DR-3SA!54%413'`55-(@>R8`@``9$B+!"4H````
M2(F$)(@"```QP$B)X6:00XL$`4N+-`$/R$B)\HG`2,'J($J)!$%(B?!(P>XX
M2,'H*"4`_P``2`GP2(G62,'B"$C!YAB!X@``_P")]D@)\$@)T$J)1$$(28/`
M"$F#^$!UKDB-L0`"```/'X``````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`
M2,'H'T@)T(/@_TB)07A(.?%UU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(
MP>H;2,'@!4@)T`,$)(V4,)EY@EI(B=A(BW0D"$@QZ$PAR$@QZ$B-M#69>8):
M1(TL`DR)RDR)R$C!Z`)(P>(>2`G"2(G838GHB=%)P>@;2#'(3"'02#'82`'P
M3(GN2,'F!4P)QD2-)`9,B=9,B=!(P>8>2,'H`D@)\$B+="0038GC2#'"2<'K
M&T&)P$PAZDB-M#.9>8):2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y(BU0D&$G!
M[0)(P>8>3`GN2#'P2(V4$9EY@EI,B=E,(>!!B?9,,<!(P>D;2`'03(G:2,'B
M!4@)RDR)X4G![`)$C2P"2,'A'DB+5"0@3`GA2(GP2#'(3(GN08G,3"'828V4
M$)EY@EI(P>X;3#'P2`'03(GJ2,'B!4@)\D2-!`),B=I(BT0D*$G!ZP)(P>(>
M3`G:3(G&2#'128V$!IEY@EI(P>X;3"'I08G33#'A2`'!3(G`2,'@!4@)\$2-
M-`A,B>A(BTPD,$G![0)(P>`>3`GH3(GV2#'"28V,#)EY@EI!B<5,(<),,=I(
M`<I,B?%(P>$%2,'N&T@)\4R)QDG!Z`)$C2012,'F'DB+5"0X3`G&2#'P3(GA
M08GP3"'P28V4$YEY@EI(P>D;3#'H2`'03(GB2,'B!4@)RDR)\4G![@)$C1P"
M2,'A'DB+5"1`3`GQ2(GP2#'(3(G>08G.3"'@28V4%9EY@EI(P>X;3#'`2`'0
M3(G:2,'B!4@)\D2-+`),B>)(BT0D2$G![`)(P>(>3`GB3(GN2#'128V$`)EY
M@EI(P>X;3"'908G43#'Q2`'!3(GH2,'@!4@)\$2-!`A,B=A(BTPD4$G!ZP)(
MP>`>3`G83(G&2#'"28V,#IEY@EI(P>X;3"'J08G#3#'B2`'*3(G!2,'A!4@)
M\4R)[DG![0)$C3012,'F'DB+5"183`GN2#'P3(GQ08GU3"'`28V4%)EY@EI(
MP>D;3#'82`'03(GR2,'B!4@)RDR)P4G!Z`)$C20"2,'A'DB+5"1@3`G!2(GP
M2#'(3(GF08G(28V4$YEY@EI,(?!(P>X;3#'H2`'03(GB2,'B!4@)\D2-'`),
MB?)(BT0D:$C!XAY)P>X"3`GR3(G>2#'128V$!9EY@EI(P>X;3"'A08G63#'!
M2`'!3(G82,'@!4@)\$2-+`A,B>!(BTPD<$G![`)(P>`>3`G@3(GN2#'"28V,
M")EY@EI(P>X;3"':08G$3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)$C0012,'F
M'DB+5"1X3`G>2#'P3(G!08GS3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B
M!4@)RDR)Z4G![0)$C30"2,'A'DB+E"2`````3`GI2(GP2#'(3(GV08G-3"'`
M28V4%)EY@EI(P>X;3#'82`'03(GR2,'B!4@)\D2-)`),B<)(BX0DB````$G!
MZ`)(P>(>3`G"3(GF2#'128V$`YEY@EI(P>X;3"'Q08G03#'I2`'!3(G@2,'@
M!4@)\$B+M"20````1(T<"$R)\$G![@)(P>`>3`GP28VT-9EY@EI-B=U(,<))
MP>T;B<%,(>),,<)(`?),B=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)
MYDR+I"28````2#'P3"'83XV$()EY@EI(,<A-B>Q)P>P;3`'`38GH2<'@!4T)
MX$6)P$P!P$V)V$G!ZP))P>`>08G$30G828GSB?9-,<-(`[0DJ````$0QVDR+
MG"2@````2HV,&:'KV6Y-B>-)P>L;2`'13(GB2,'B!4P)VHG22`'13(GJ2<'M
M`DC!XAY!B<M,">I-B<5%B<!),=5,`X0DL````$0QZ$V)W4B-M`:AZ]EN3(G8
M2<'M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-
MB>Q(`Y0DN````$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(
MP>$>18G$3`G928GSB?9),<M(`[0DP````$0QV$V)XTB-E`*AZ]EN3(G@2<'K
M&TC!X`5,"=B)P$@!PDR)Z$G![0)(P>`>08G33`GH28G-B<E),<5(`XPDR```
M`$4QZ$V)W4Z-A`:AZ]EN3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>
M08GU30G@28G$B<!-,<1$,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-``
M``!,">*)TD@!T4R)VDG!ZP)(P>(>08G,3`G:38G#18G`23'33`.$)-@```!$
M,=Y-B>-(C;0PH>O9;DR)X$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)
MPTP)[DF)U8G223'U2`.4).````!$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%
M3`GIB<E)`<A,B>%)P>P"2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'K
MV6Y,B>A)P>P;2,'@!4P)X(G`2`'"3(G82`.T).@```!)P>L"2,'@'D&)U$P)
MV$F)RXG)23'#2`.,)/````!%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>
MB?9,`<9-B>A)P>T"2<'@'D&)\TT)Z$F)Q8G`33'%2`.$)/@```!$,>I-B=U(
MC8P1H>O9;DR)VDG![1M(P>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)
MQ$6)P$DQU$0QYDV)[$B-M#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!
MYAY)P>L"3`.$)``!``!,"=Y)B=-!B<1),?.)TD@#E"0(`0``1#'938GC38V$
M"*'KV6Y,B>%)P>L;2,'A!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)
M]DDQS4@#M"00`0``1#'H38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"
M3(G@2<'L`DC!X!Y!B=5,">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L
M&TC!Y@5,">:)]DP!QDV)V$G!ZP))P>`>08GT30G82`.,)!@!``!)B<--,<.)
MP$@#A"0@`0``1#':38GC2<'K&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ
M2<'M`DC!XAY!B<M,">I-B<5%B<!),=5,`X0D*`$``$0Q[DV)W4B-M#"AZ]EN
M3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(
M`Y0D,`$``$0QX4V)[$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!
MZP)(P>$>18G$3`G928GSB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@
M2<'K&TC!X`5,"=A$C1P03(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=
M3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>
M30G@3`G`1(G&28G$2(G02"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)
MP>T;2,'A!4P)Z4F)]4$!S$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH
M3(NL)$@!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"
M2,'B'DP)\DV)WD&)T$@)T4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q
M3(GN2<'N&TC!Y@5,"?9$C30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PA
MZDP)XDR+I"18`0``20'$30'C38GT3`':38GS2<'C!4G![!M-">-%C20338GK
M2<'M`DG!XQY-">M)B<U$B=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)
MY4P!QDV)X$G![1M)P>`%30GH18TL,$V)\$G![@))P>`>30GP28G61(G&30G#
M22'V32'C30GS3(NT)&@!``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:-
M-!E,B>%)P>P"2,'A'DP)X4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$
M3`'B38GT20'03(GR2<'L&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!
MB=!("=%-(<5,(?%,">E,BZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%
M3`GN1(TL#DR)]DG![@)(P>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$`
M`$D!QDT!\TV)[DP!VDV)ZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC
M28G,1(G:3`G>22'43"'N3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;
M2<'@!4T)X$6-)#!-B>A)P>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+
MK"20`0``20'%3`'I38GE20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!
MX1Y,"?%)B?9)"<A!B<M-(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)
MZDG![AM(P>(%3`GR1HTT`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$3"'I
M3`GA3(ND)*`!``!)`<1,`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)
MP>T"2,'F'DP)[DV)Q8GQ2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,
M`=I-B>-)P>T;2<'C!4T)ZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDA
MUDPAYDP)]DR+M"2P`0``20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P
M38G@2<'L`DG!X!Y-">!)B=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!
MX4V)]$D!RTR)\4G![!M(P>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+
M20G(32'P32'=30GH3(NL),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)
MZD:-+`),B?))P>X"2,'B'DV)V$P)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``
M20'`3`'&38GH2`'Q3(GN2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,
M">9!B?1("?),(>%,(>I("<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':
M38G#2,'A!4G!ZQM,"=F)R4P!\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/
M2`G.32']3"'&3`GN38G=2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(
MP>8>08G%20GPOM;!8LI,,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A
M!4G![!M,">&)R4@!RDR)V4C!X1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)
MP#'(2(N,).@!``!(`?%)`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(
MP>`>3(G918G;20G%2(N$)/`!``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),
MB?A(P>`%2`G(2(N,)/@!``")P$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'9
M38GK23'#38G$18GM13'>2<'L&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"
M2,'A'D6)W$D)STB+C"0``@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA
M2,'I&TC!X@5("<I,B<%)P>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A%B>Y%
MB?]),<A(`?)%,<-(`=!,B?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`
M3(G@2<'L`DC!X!Y%B<-)"<1(BX0D$`(``$PQXD$QU4R)VD@!\$P!^$D!Q4R)
MV$C!X`5(P>H;2`G03(GR2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P
M2`'(3(GA18GD2#'103'(3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!
MZP)(P>`>18G&20G#2(N$)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.
MC20H3(GP2,'@!4@)R$B+C"0H`@``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)
M^$@!RDR)V4@QP46)VT$QR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))
MP>X"2,'B'D6)QTD)UDB+E"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<
M3HT<(DR)^DC!X@5("<I,B>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(
M`?)(`=!,B?)%B?9(,<I!,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)
M`<!,B?A)P>\"2,'@'D6)Q4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#
M3(GH2,'J&TC!X`5("=!,B>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)
MB=1(`?!(`<A,B?E%B?](,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`
M2`'!3(GH2<'M`DC!X!Y!B<A)"<5(BX0D4`(``$TQ[$4QXTV)Q$@!\$G![!M,
M`?A)`<-,B<!(P>`%3`G@B<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``
M20'V20'63(GJ18GM2#'",=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)
MP4G!Z`)(P>$>08G620G(2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!
MRTR)\4G![1M(P>$%3`GIB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``
M2`'Q2`'(3(G!18G`3#'A,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"
M2,'B'HG`20G62(N4)'`"``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)
MPTG!X`5)P>L;30G828G#2,'H`DG!XQY!`=!,B>I)"<-(BX0D>`(``$C!XAY)
MP>T"00';20G51(GB3(E?$$@!\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),
MB<%(P>(%2,'I&T4!R$@)RDR)1P@!T$$!PD0#=R!(BX0DB`(``&1(,P0E*```
M`$R)%TR)=R!U$DB!Q)@"``!;74%<05U!7D%?P^BRR?__9I!(@^P(OX````#H
MPLK__[J)J\WON?[<NIB^\.'2PTC'``$C16=(B5`(2(E($$C'0!AV5#(02(EP
M($C'0"@`````2,=`,`````#'0'@`````2(/$",-F9BX/'X0``````)!!5T%6
M2&/"055!5$F)Q5532(GS28G\2(/L"$B+=RA(BU<P28UL)#B-#,9(.?%(B4\H
M2(/2`$C!Z!U(`=!(B4<P2&-_>(7_=%A!OT````!(B=Y!*?]%.?U%#T[]2`'O
M36/W3(GRZ,?)__]!BT0D>$0!^(/X0$&)1"1X=!5(@\0(6UU!7$%=05Y!7\-F
M#Q]$``!,B>=%*?U,`?/H\NC__V:008/]/WY508/M0$6)[T'![P9%B?Y)@\8!
M2<'F!DD!WI#S#V\#3(GG2(/#0`\110#S#V]#T`\111#S#V]#X`\112#S#V]#
M\`\113#HH>C__TPY\W7,0<'G!D4I_4ECQ4B#^`AR7$B+$TF)5"0X2(M4`_A(
MB50%^$B-50A(@^+X2"G52"GK2`'%2(/E^$B#_0AR%TB#Y?@QP$B+#`-(B0P"
M2(/`"$@YZ'+O18EL)'A(@\0(6UU!7$%=05Y!7\,/'T``J`1U'4B%P'3?#[83
MJ`)!B%0D.'33#[=4`_YFB50%_NO'BQ-!B50D.(M4`_R)5`7\Z[9F9BX/'X0`
M``````\?`$%6055,C78X05152(G]4TR+9BA(B?-,BVXP3(G@2,'H`X/@/XU(
M`4B8QD0&.(!(8\%,`?"#^3@/CYL!``"Z.````#'V*<J#^@@/@F$!``")T4C'
M``````!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(<A*#XO@QP(G'@\`(
M.=!(B30Y<O-,B>A$B&MS1(AC=TC!Z!A(B=^(0W!,B>A(P>@0B$-Q3(GH2,'H
M"(A#<DR)X$C!Z!B(0W1,B>!(P>@0B$-U3(G@2,'H"(A#=N@<Y___2(L#2(G?
M2,'H&(A%`$B+`TC!Z!"(10%(BP-(P>@(B$4"2(L#B$4#2(M#"$C!Z!B(101(
MBT,(2,'H$(A%!4B+0PA(P>@(B$4&2(M#"(A%!TB+0Q!(P>@8B$4(2(M#$$C!
MZ!"(10E(BT,02,'H"(A%"DB+0Q"(10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-
M2(M#&$C!Z`B(10Y(BT,8B$4/2(M#($C!Z!B(11!(BT,@2,'H$(A%$4B+0R!(
MP>@(B$422(M#((A%$UM=05Q!74%>Z1C%__\/'X0``````/;"!'5KA=(/A,O^
M___VP@+&```/A+_^__\QR6:)3!#^Z;/^__\/'P"Z0````"G*=`\QR8G.@\$!
M.='&!#``<O-(B=_H^.7__V8/[\`/$4,X2<=&,`````!!#Q%&$$$/$48@Z7'^
M__]F#Q^$``````#'``````#'1!#\`````.E5_O__9BX/'X0```````\?`)"0
MD)"0D)"0D)"0D)"0D)!!5T%628G7055!5$R-)7YB``!52(TM?F(``%-!B?U)
MB?9,*>5(@^P(2,']`^@/Q/__2(7M="`QVP\?A```````3(GZ3(GV1(GO0?\4
MW$B#PP%(.=UUZDB#Q`A;74%<05U!7D%?PV9F+@\?A```````D)"0D)"0D)"0
MD)"0D)"0D//#9BX/'X0```````\?0`"0D)"0D)"0D)"0D)"0D)"02(L-868`
M`.DTQ?__2(/L"$B#Q`C#`````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ
M0D]/5``O<')O8R\E:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%
M4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%
M1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!0
M05)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL
M960`<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`"]T
M;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M`'!A
M<FP`+G!A<@!S:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D52
M4TE/3@`Q+C`V,P`M90`M+0```"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O
M(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F
M9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@
M(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'
M24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@
M*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@
M*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES
M(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@
M>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X
M*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D[
M"GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M
M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M
M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M
M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?
M<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA
M;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ
M<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!
M4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#
M2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII
M9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*
M;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*
M;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(
M+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C
M:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%
M<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T
M:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M
M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^
M8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E
M:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I
M;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z
M("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:
M25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S
M96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C
M('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?
M<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U
M="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2![
M"G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI]
M(&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L
M;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG
M+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N
M.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F
M:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R
M+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P
M<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`]
M(#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH
M)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A
M73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP
M*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O
M9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I
M;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N
M86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F
M:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*
M)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C
M86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!
M0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'
M24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL
M97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)
M3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@
M)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H
M(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S
M:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O
M("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM
M>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H
M*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@
M)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L
M(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^
M(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S
M92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S
M>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E
M;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F
M:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB
M4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P
M97)L>'-I+F,````!&P,[&`$``"(````L@___9`$``*R&__^,`0``O(;__S0&
M``#\B/__-`$```R*__^D`0``W(K___`!``!LB___'`(``+R-__]H`@``/(__
M_[0"``#<C___V`(``+R0__\<`P``C)'__TP#``"\D?__9`,```R2__]\`P``
MW)+__Z@#``#LDO__O`,```R5__\<!```/)7__S@$``",E?__7`0``!R7__^`
M!```?)?__YP$```\F/__M`0``%R9___L!```C)G__P@%``!<FO__2`4``'RA
M___@!0``#*3__Q0&``!LI/__9`8``'RZ__^T!@``W+K__\P&``!\O/__,`<`
M`,J^__]T!P``2K___[P'``!JO___U`<``!0``````````7I2``%X$`$;#`<(
MD`$'$!0````<````P(?__RL``````````````!0``````````7I2``%X$`$;
M#`<(D`$``"0````<````P('__X`#````#A!&#AA*#PMW"(``/QH[*C,D(@``
M```4````1````!B%__\(``````````````!(````7````&"(___,`````$(.
M$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@
M0@X80@X00@X(20L`*````*@```#DB/__A`````!!#A"&`D$.&(,#1PXP`G,*
M#AA!#A!!#@A!"P!(````U````$B)__],`@```$(.$(\"0@X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!TH.8`,F`0H..$$.,$$.*$(.($(.&$(.$$(."$0+2```
M`"`!``!,B___>0$```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='
M#O`!?@H..$$.,$$.*$(.($(.&$(.$$(."$<+`"````!L`0``@(S__Y0`````
M00X0@P)2#K`!`E,*#A!!#@A)"T````"0`0``_(S__]X`````0@X0C@)"#AB-
M`T4.((P$00XHA@5$#C"#!E,.P"`"A`H.,$$.*$$.($(.&$(.$$(."$,++```
M`-0!``"8C?__Q`````!!#A"#`D\.H"`">@H.$$$."$4+8@H.$$@."$4+````
M%`````0"```XCO__,`````!$#A!G#@@`%````!P"``!0CO__20````!$#A!]
M#@@`*````#0"``"(CO__P0````!!#A"&`D$.&(,#1P[`0`*G"@X800X000X(
M1@L0````8`(``"R/__\%`````````%P```!T`@``*(___QH"````0@X0CP)"
M#AB.`T(.((T$0@XHC`5$#C"&!D$..(,'40[P(0)D"@XX00XP00XH0@X@0@X8
M0@X00@X(1`L"L0[X(4\.@")J#O@A00[P(0```!@```#4`@``Z)#__R(`````
M00X0@P)<#@@````@````\`(``/R0__]$`````$L.$(,"6,,."%T.$(,"0PX(
M```@````%`,``"B1__^&`0```$$.$(,"2PX@`T0!"@X000X(1PL8````.`,`
M`)22__]=`````$0.(`)3"@X(00L`%````%0#``#8DO__L@````!'#N`!````
M-````&P#``"`D___'@$```!"#A",`D$.&(8#1@X@@P1,#K"`!`+$"@X@00X8
M00X00@X(0PL````8````I`,``&B4__\D`````$0.$%@*#@A$"P``/````,`#
M``!\E/__S@````!"#A",`D$.&(8#1`X@@P1+#C`"3`H.($$.&$$.$$(."$8+
M80XX3PY`;@XX00XP`)0`````!```#)7__QT'````0@X0CP)"#AB.`T(.((T$
M0@XHC`5$#C"&!D$..(,'3@ZP`P,=`@ZX`U8.P`-E#K@#0@ZP`P,,`0H..$$.
M,$$.*$(.($(.&$(.$$(."$4+`W(!#K@#2`[``V$.N`-!#K`#6@ZX`TD.P`-!
M#L@#1`[0`UT.L`,##0$.N`-!#L`#4@ZX`T$.L`,`,````)@$``"4F___C0(`
M``!"#A",`D$.&(8#00X@@P1$#C`#T@$*#B!!#AA!#A!"#@A""QP```#,!```
M\)W__U,`````00X0@P)9"@X(1@MN#@@`+````.P$``"`@/__,@(```!!#A"&
M`D$.&(,#1`Y0`[8!"@X800X000X(00L`````3````!P%````GO__#A8```!"
M#A"/`D(.&(X#1@X@C01"#BB,!40.,(8&00XX@P='#M`%`^85"@XX00XP00XH
M0@X@0@X80@X00@X(00L````4````;`4``,"S__]4`````$0.$`)/#@A@````
MA`4```BT__^2`0```$(.$(\"0@X8C@-%#B"-!$(.*(P%1`XPA@9!#CB#!TH.
M0`)E"@XX00XP00XH0@X@0@X80@X00@X(1PL"P0H..$$.,$$.*$(.($(.&$(.
M$$(."$4+0````.@%``!$M?__,P(```!"#A".`D(.&(T#1@X@C`1!#BB&!40.
M,(,&`XT!"@XH00X@0@X80@X00@X(30L```````!$````+`8``$ZW__]G````
M`$0.$(\"0@X8C@-%#B"-!$(.*(P%2`XPA@9(#CB#!TT.0'(..$$.,$$.*$(.
M($(.&$(.$$(."``4````=`8``(:W__\$```````````````0````C`8``(ZW
M__\.````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M,"0```````#P(P````````````````````````````````````````$`````
M````"@,````````!`````````!4#`````````0`````````E`P```````!T`
M````````N`0````````,`````````$`=````````#0````````"L60``````
M`!D`````````D+L````````;``````````@`````````&@````````"8NP``
M`````!P`````````"``````````$`````````)@"````````]?[_;P````"P
M!0````````4``````````!`````````&`````````+@&````````"@``````
M``#M!`````````L`````````&``````````5`````````````````````P``
M``````#HO0````````(`````````*`4````````4``````````<`````````
M%P`````````8&`````````<`````````.!8````````(`````````.`!````
M````"0`````````8`````````!X`````````"`````````#[__]O``````$`
M``@`````_O__;P````"X%0```````/___V\``````@````````#P__]O````
M`.X4````````^?__;P`````'````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````N+L`````````````````````````````=AT`````
M``"&'0```````)8=````````IAT```````"V'0```````,8=````````UAT`
M``````#F'0```````/8=````````!AX````````6'@```````"8>````````
M-AX```````!&'@```````%8>````````9AX```````!V'@```````(8>````
M````EAX```````"F'@```````+8>````````QAX```````#6'@```````.8>
M````````]AX````````&'P```````!8?````````)A\````````V'P``````
M`$8?````````5A\```````!F'P```````'8?````````AA\```````"6'P``
M`````*8?````````MA\```````#&'P```````-8?````````YA\```````#V
M'P````````8@````````%B`````````F(````````#8@````````1B``````
M``!6(````````&8@````````=B````````"&(````````)8@````````IB``
M``````"V(````````,8@````````UB``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````+!<
M````````\%@```````!P60```````)!9````````1T-#.B`H4U5312!,:6YU
M>"D@-RXU+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO
M=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?
M:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR
M96PN<F\`+F1Y;F%M:6,`+F1A=&$`7U]P871C:&%B;&5?9G5N8W1I;VY?96YT
M<FEE<P`N8G-S`"YC;VUM96YT````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````.`(````````X`@```````!P````````````````````!````
M````````````````$P````<````"`````````%0"````````5`(````````@
M````````````````````!````````````````````"$````'`````@``````
M``!T`@```````'0"````````)`````````````````````0`````````````
M```````X````!0````(`````````F`(```````"8`@```````!@#````````
M!@`````````(``````````0`````````-````/;__V\"`````````+`%````
M````L`4````````$`0````````8`````````"````````````````````#X`
M```+`````@````````"X!@```````+@&````````2`D````````'`````0``
M``@`````````&`````````!&`````P````(``````````!``````````$```
M`````.T$```````````````````!````````````````````3@```/___V\"
M`````````.X4````````[A0```````#&``````````8``````````@``````
M```"`````````%L```#^__]O`@````````"X%0```````+@5````````@```
M```````'`````@````@```````````````````!J````!`````(`````````
M.!8````````X%@```````.`!````````!@`````````(`````````!@`````
M````=`````0```!"`````````!@8````````&!@````````H!0````````8`
M```8````"``````````8`````````'X````!````!@````````!`'0``````
M`$`=````````%P````````````````````0```````````````````!Y````
M`0````8`````````8!T```````!@'0```````(`#```````````````````0
M`````````!``````````A`````$````&`````````.`@````````X"``````
M```(````````````````````"``````````(`````````(T````!````!@``
M``````#P(````````/`@````````O#@``````````````````!``````````
M``````````"3`````0````8`````````K%D```````"L60````````D`````
M```````````````$````````````````````F0````$````"`````````+A9
M````````N%D```````!Z0```````````````````"```````````````````
M`*$````!`````@`````````TF@```````#2:````````'`$`````````````
M``````0```````````````````"O`````0````(`````````4)L```````!0
MFP```````-`&```````````````````(````````````````````N0````X`
M```#`````````)"[````````D*L````````(````````````````````"```
M```````(`````````,4````/`````P````````"8NP```````)BK````````
M"`````````````````````@`````````"`````````#1`````0````,`````
M````H+L```````"@JP```````!,````````````````````0````````````
M````````W@````8````#`````````+B[````````N*L````````P`@``````
M``<`````````"``````````0`````````(@````!`````P````````#HO0``
M`````.BM````````$`(```````````````````@`````````"`````````#G
M`````0````,``````````,``````````L````````"@`````````````````
M```(````````````````````[0````$```"#`````````"C`````````*+``
M```````8``````````\`````````"`````````````````````H!```(````
M`P````````!`P````````$"P````````<````````````````````"``````
M```````````````/`0```0```#````````````````````!`L````````!@`
M```````````````````!``````````$``````````0````,`````````````
M````````````6+`````````8`0```````````````````0``````````````
$````````
